#
# spec file for package xml-security
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global oname xmlsec
%global _version 2_1_7
Name:           xml-security
Version:        2.1.7
Release:        5.4
Summary:        Apache XML Security for Java
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://santuario.apache.org/
Source0:        https://archive.apache.org/dist/santuario/java-library/%{_version}/%{oname}-%{version}-source-release.zip
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  unzip
BuildRequires:  mvn(com.fasterxml.woodstox:woodstox-core)
BuildRequires:  mvn(commons-codec:commons-codec)
BuildRequires:  mvn(javax.xml.bind:jaxb-api)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache:apache:pom:)
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildRequires:  mvn(xalan:xalan)
BuildRequires:  mvn(xerces:xercesImpl)
BuildRequires:  mvn(xml-apis:xml-apis)
BuildArch:      noarch

%description
Apache XML Security for Java supports XML-Signature Syntax and Processing,
W3C Recommendation 12 February 2002, and XML Encryption Syntax and
Processing, W3C Recommendation 10 December 2002. As of version 1.4,
the library supports the standard Java API JSR-105: XML Digital Signature APIs.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n %{oname}-%{version}

%pom_remove_plugin :maven-pmd-plugin
%pom_remove_plugin :maven-source-plugin
%pom_remove_plugin :maven-javadoc-plugin

%pom_xpath_remove pom:plugin/pom:configuration/pom:compilerArgs
%pom_xpath_remove pom:plugin/pom:configuration/pom:annotationProcessorPaths

%pom_xpath_remove pom:profiles

%pom_add_dep javax.xml.bind:jaxb-api::provided

%{mvn_file} :%{oname} %{name} %{oname}

%build
%{mvn_build} -f -- \
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ) \
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE

%changelog
* Tue Sep 19 2023 Fridrich Strba <fstrba@suse.com>
- Do not require maven-javadoc-plugin that we don't use
* Mon Sep 11 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Wed Mar 30 2022 Fridrich Strba <fstrba@suse.com>
- Build against the standalone JavaEE modules inconditionally
* Fri Mar 18 2022 Fridrich Strba <fstrba@suse.com>
- Build against a standalone jaxb-api artifact on systems where the
  JDK does not include the JavaEE modules
* Fri Dec 17 2021 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 2.1.7 (bsc#1193879, CVE-2021-40690)
- Changes of 2.1.7
  * Improvement
    + [SANTUARIO-572] - Disallow a KeyInfoReference to refer to a
    RetrievalMethod
    + [SANTUARIO-577] - Introduce a system property to control if
    file/http references are allowed from an unsigned context
- Changes of 2.1.6
  * Bug
    + [SANTUARIO-542] - SignatureProperties incorrectly gets sibling
    nodes of the parent element, instead of the child elements
    + [SANTUARIO-553] - JCE provider being resolved without key
    causes wrong provider to be selected
    + [SANTUARIO-556] - WeakHashMap cache cause infinite loop
- Changes of 2.1.5
  * Bug
    + [SANTUARIO-508] - NPE in XMLSignatureInput
    + [SANTUARIO-512] - security-config.xml is out of date
    + [SANTUARIO-514] - XMLSignature processes KeyInfo elements
    twice
    + [SANTUARIO-515] - XMLSignature does not enforce structure of
    the ds:Signature element
    + [SANTUARIO-523] - XMLSecurityStreamReader ignores information
    in XML document declaration
    + [SANTUARIO-524] - Unable to pass Provider to HMAC
    SignatureMethod
    + [SANTUARIO-526] - XMLSecStartDocumentImpl returns null version
    instead of default "1.0"
- Changes of 2.1.4
  * Fixes CVE-2019-12400: Apache Santuario potentially loads XML
    parsing code from an untrusted source.
  * Improvement
    + [SANTUARIO-507] - Deprecate WeakObjectPool DocumentBuilder
    cache
  * Task
    + [SANTUARIO-505] - Remove Doctypes from the streaming schemas
* Fri Jul 10 2020 Fridrich Strba <fstrba@suse.com>
- Initial packaging of xml-security 2.1.3
